# aifund

#### 介绍

AIfund 是基于 Python 的基金量化工具

#### 安装

```shell
pip install aifund --upgrade
```

#### 现有方法

```python
import aifund

aifund.lock_string(123)

aifund.stock_chart

aifund.fund_etf_fund_info_em

aifund.get_price

aifund.etf_daily

```